==> scala-relay-compiler-0.4.0.tgz: package/example/out/DictionaryComponent_word.scala <==
/**
 * scala 
 * Generated, DON'T MANUALLY EDIT.
 */
package relay.generated;
/*::
import type {ConcreteFragment} from 'relay-runtime';

objName:      fragment
docType:      ConcreteFragment
concreteText: {
  "argumentDefinitions": [],
  "kind": "Fragment",
  "metadata": null,
  "name": "DictionaryComponent_word",
  "selections": [
    {
      "kind": "ScalarField",
      "alias": null,
      "args": null,
      "name": "id",
      "storageKey": null
    },
    {
      "kind": "LinkedField",
      "alias": null,
      "args": null,
      "concreteType": "WordDefinition",
      "name": "definition",
      "plural": false,
      "selections": [
        {
          "kind": "FragmentSpread",
          "name": "DictionaryComponent_definition",
          "args": null
        },
        {
          "kind": "ScalarField",
          "alias": null,
          "args": null,
          "name": "text",
          "storageKey": null
        },
        {
          "kind": "ScalarField",
          "alias": null,
          "args": null,
          "name": "id",
          "storageKey": null
        }
      ],
      "storageKey": null
    }
  ],
  "type": "Word"
};
*/

import _root_.scala.scalajs.js

trait DictionaryComponent_word extends js.Object {
  /** New fields added, conflicts detected. */ 
   val definition : DictionaryComponent_word.Definition
   val id : String
}


object DictionaryComponent_word  {

  trait Definition extends js.Object {
   val id : String
   val text : String
  /** getDirectMembersForFrag child of DictionaryComponent_definition */ 
   val image : String
}

  val ast: _root_.scala.scalajs.js.Any = _root_.scala.scalajs.js.eval("""{
  "argumentDefinitions": [],
  "kind": "Fragment",
  "metadata": null,
  "name": "DictionaryComponent_word",
  "selections": [
    {
      "kind": "ScalarField",
      "alias": null,
      "args": null,
      "name": "id",
      "storageKey": null
    },
    {
      "kind": "LinkedField",
      "alias": null,
      "args": null,
      "concreteType": "WordDefinition",
      "name": "definition",
      "plural": false,
      "selections": [
        {
          "kind": "FragmentSpread",
          "name": "DictionaryComponent_definition",
          "args": null
        },
        {
          "kind": "ScalarField",
          "alias": null,
          "args": null,
          "name": "text",
          "storageKey": null
        },
        {
          "kind": "ScalarField",
          "alias": null,
          "args": null,
          "name": "id",
          "storageKey": null
        }
      ],
      "storageKey": null
    }
  ],
  "type": "Word"
}""")
  val query: String = """"""
}

==> scala-relay-compiler-0.5.0.tgz: package/example/out/DictionaryComponent_word.scala <==
/**
 * scala 
 * Generated, DON'T MANUALLY EDIT.
 */
package relay.generated
/*

objName:      fragment
docType:      ConcreteFragment
*/

import _root_.scala.scalajs.js

trait DictionaryComponent_word extends js.Object {
  /** New fields added, conflicts detected. */ 
   val definition : DictionaryComponent_word.Definition
   val id : String
}


object DictionaryComponent_word extends _root_.relay.graphql.GenericGraphQLTaggedNode {

  trait Definition extends js.Object {
   val id : String
   val text : String
  /** getDirectMembersForFrag child of DictionaryComponent_definition */ 
   val image : String
}

  val query: _root_.relay.graphql.ConcreteFragment = _root_.scala.scalajs.js.JSON.parse("""{
  "argumentDefinitions": [],
  "kind": "Fragment",
  "metadata": null,
  "name": "DictionaryComponent_word",
  "selections": [
    {
      "kind": "ScalarField",
      "alias": null,
      "args": null,
      "name": "id",
      "storageKey": null
    },
    {
      "kind": "LinkedField",
      "alias": null,
      "args": null,
      "concreteType": "WordDefinition",
      "name": "definition",
      "plural": false,
      "selections": [
        {
          "kind": "FragmentSpread",
          "name": "DictionaryComponent_definition",
          "args": null
        },
        {
          "kind": "ScalarField",
          "alias": null,
          "args": null,
          "name": "text",
          "storageKey": null
        },
        {
          "kind": "ScalarField",
          "alias": null,
          "args": null,
          "name": "id",
          "storageKey": null
        }
      ],
      "storageKey": null
    }
  ],
  "type": "Word"
}""").asInstanceOf[_root_.relay.graphql.ConcreteFragment]
  val devText: String = """"""
}
